@@ -2,9 +2,9 @@
 
 
 /**
-  * SquirrelMail Quicksave Plugin
+  * SquirrelMail Quick Save Plugin
   * Copyright (c) 2001-2002 Ray Black <allah@accessnode.net>
-  * Copyright (c) 2003-2007 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2010 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -33,9 +33,12 @@ function squirrelmail_plugin_init_quicksave()
 
 
 
-   // SquirrelMail 1.4.x (although the first hook here also
-   // has a touch of 1.5.x code in it too)
+   // SquirrelMail 1.4.x (although the first two hooks here 
+   // also have a touch of 1.5.x code in them too)
    //
+   $squirrelmail_plugin_hooks['right_main_after_header']['quicksave']
+      = 'quicksave_check_recovery_upon_login';
+
    $squirrelmail_plugin_hooks['compose_send']['quicksave']
       = 'quicksave_message_sent';
 
@@ -49,6 +52,9 @@ function squirrelmail_plugin_init_quicksave()
 
    // SquirrelMail 1.5.x
    //
+   $squirrelmail_plugin_hooks['template_construct_motd.tpl']['quicksave']
+      = 'quicksave_check_recovery_upon_login';
+
    $squirrelmail_plugin_hooks['compose_send_after']['quicksave']
       = 'quicksave_message_sent';
 
@@ -76,10 +82,16 @@ function quicksave_info()
 {
 
    return array(
-             'english_name' => 'Quicksave',
+             'english_name' => 'Quick Save',
+             'authors' => array(
+                'Paul Lesniewski' => array(
+                   'email' => 'paul@squirrelmail.org',
+                   'sm_site_username' => 'pdontthink',
+                ),
+             ),
              'summary' => 'Automatically saves messages as they are being composed to prevent accidental loss due to leaving the compose screen or browser/computer crashes.',
              'details' => 'This plugin automatically saves messages as they are being composed in order to prevent accidental loss of message content due to having browsed away from the compose screen or more serious problems such as browser or computer crashes.  When a message appears to have been lost and is available for recovery, the user will be prompted about whether or not the recovery should proceed.',
-             'version' => '2.4',
+             'version' => '2.4.4',
              'required_sm_version' => '1.2.9',
              'requires_configuration' => 0,
              'requires_source_patch' => 0,
@@ -153,6 +165,21 @@ function quicksave_version()
 
 
 
+/**
+  * Determine whether or not to offer message 
+  * recovery upon login
+  *
+  */
+function quicksave_check_recovery_upon_login($args)
+{
+
+   include_once(SM_PATH . 'plugins/quicksave/login_functions.php');
+   return quicksave_check_recovery_upon_login_do($args);
+
+}
+
+
+
 /**
   * Present user quicksave preferences on display/compose
   * options page for SquirrelMail 1.5.x
@@ -246,7 +273,7 @@ function quicksave_compose_functions()
 function quicksave_check_configuration()
 {
 
-   include_once(SM_PATH . 'plugins/quicksave/functions.php');
+   include_once(SM_PATH . 'plugins/quicksave/common_functions.php');
    return quicksave_check_configuration_do();
 
 }
